@@ -11,6 +11,7 @@ __all__ = [
     "IOPIS_NSGAIII",
     "IOPIS_RVEA",
     "MOEA_D",
+    "IBEA"
 ]
 
 from desdeo_emo.EAs.BaseEA import BaseEA, BaseDecompositionEA
@@ -20,3 +21,4 @@ from desdeo_emo.EAs.PPGA import PPGA
 from desdeo_emo.EAs.TournamentEA import TournamentEA
 from desdeo_emo.EAs.IOPIS import IOPIS_NSGAIII, IOPIS_RVEA
 from desdeo_emo.EAs.MOEAD import MOEA_D
+from desdeo_emo.EAs.IBEA import IBEA
