@@ -8,6 +8,8 @@ __all__ = [
     "EvoDN2Recombination",
     "BioGP_xover",
     "BioGP_mutation",
+    "SinglePoint_Xover",
+    "SinglePoint_Mutation",
 ]
 
 from desdeo_emo.recombination.biogp_mutation import BioGP_mutation
@@ -16,3 +18,4 @@ from desdeo_emo.recombination.BoundedPolynomialMutation import BP_mutation
 from desdeo_emo.recombination.evodn2_xover_mutation import EvoDN2Recombination
 from desdeo_emo.recombination.evonn_xover_mutation import EvoNNRecombination
 from desdeo_emo.recombination.SimulatedBinaryCrossover import SBX_xover
+from desdeo_emo.recombination.SinglePointCrossoverMutation import SinglePoint_Xover, SinglePoint_Mutation
